@@ -59,7 +59,7 @@ sub import {
 }
 
 
-our $VERSION = '0.0251';    # VERSION
+our $VERSION = '0.0252';    # VERSION
 
 1;
 
@@ -77,7 +77,7 @@ Evo - Evo - the next generation development framework
 
 =head1 VERSION
 
-version 0.0251
+version 0.0252
 
 =head1 DESCRIPTION
 
@@ -93,7 +93,7 @@ It provides rewritten and postmodern features like
 [almost ready] Post modern code injection programming L<Evo::Class> instead of traditional OO
 
 =item *
-[almost ready] Fast non recursive "Promise" role, 100% "Promise/Spec A" compatible. + See L<Mojo::Promise>
+[almost ready] Fast non recursive "Promise" role, 100% "Promise/Spec A" compatible. + See L<Evo::Promise::Mojo>
 
 =item *
 (almost ready) Exception handling in pure perl: L<Evo::Lib/try>, like "try catch" but perl way.
